__author__ = 'viet.pham'
__copyright__ = 'GiQ GmbH'
__date__ = '30.07.2015'
__version__ = '0.0.1'
__status__ = 'beta'

from distutils.core import setup

setup(
    name='nagios',
    version='0.0.2',
    packages=['nagios'],
    url='',
    #license='APACHE LICENSE 2.0',
    author='Viet Pham',
    author_email='viet.pham@getgoods.de',
    description='module to develop plugin for nagios, icinga',
    keywords=['nagios', 'icinga', 'plugin'],
)
